@@ -8,7 +8,7 @@ from lightwood.analysis.nc.calibrate import ICP
 from lightwood.analysis.helpers.acc_stats import AccStats
 from lightwood.analysis.helpers.conf_stats import ConfStats
 from lightwood.analysis.nn_conf.temp_scale import TempScaler
-from lightwood.analysis.helpers.feature_importance import GlobalFeatureImportance
+from lightwood.analysis.helpers.feature_importance import PermutationFeatureImportance
 
 try:
     from lightwood.analysis.helpers.shap import ShapleyValues
@@ -17,4 +17,4 @@ except Exception:
 
 
 __all__ = ['model_analyzer', 'explain', 'BaseAnalysisBlock', 'TempScaler',
-           'ICP', 'AccStats', 'ConfStats', 'GlobalFeatureImportance', 'ShapleyValues']
+           'ICP', 'AccStats', 'ConfStats', 'PermutationFeatureImportance', 'ShapleyValues']
