@@ -194,7 +194,7 @@ def generate_json_ai(
     tss = problem_definition.timeseries_settings
     dtype_dict = type_information.dtypes
     for k in type_information.identifiers:
-        if not (tss.is_timeseries and tss.group_by and k in tss.group_by):
+        if not (tss.is_timeseries and tss.group_by and k in tss.group_by) and k != target:
             del dtype_dict[k]
     dependency_dict = {}
 
@@ -326,9 +326,6 @@ def generate_json_ai(
         "module": "BestOf",
         "args": {
             "submodels": submodels,
-            "args": "$pred_args",
-            "accuracy_functions": "$accuracy_functions",
-            "ts_analysis": "self.ts_analysis" if is_ts else None,
         }
     }
 
@@ -528,20 +525,45 @@ def _add_implicit_values(json_ai: JsonAI) -> JsonAI:
     tss = problem_definition.timeseries_settings
     is_ts = tss.is_timeseries
 
-    # Add implicit arguments
+    # Add implicit ensemble arguments
+    json_ai.model["args"]["target"] = json_ai.model["args"].get("target", "$target")
+    json_ai.model["args"]["data"] = json_ai.model["args"].get("data", "encoded_test_data")
+    json_ai.model["args"]["mixers"] = json_ai.model["args"].get("mixers", "$mixers")
+    json_ai.model["args"]["fit"] = json_ai.model["args"].get("fit", True)
+    json_ai.model["args"]["args"] = json_ai.model["args"].get("args", "$pred_args")  # TODO correct?
+
+    # @TODO: change this to per-parameter basis and signature inspection
+    if json_ai.model["module"] in ("BestOf", "ModeEnsemble", "WeightedMeanEnsemble"):
+        json_ai.model["args"]["accuracy_functions"] = json_ai.model["args"].get("accuracy_functions",
+                                                                                "$accuracy_functions")
+
+    if json_ai.model["module"] in ("BestOf", "TsStackedEnsemble", "WeightedMeanEnsemble"):
+        tsa_val = "self.ts_analysis" if is_ts else None
+        json_ai.model["args"]["ts_analysis"] = json_ai.model["args"].get("ts_analysis", tsa_val)
+
+    if json_ai.model["module"] in ("MeanEnsemble", "ModeEnsemble", "StackedEnsemble", "TsStackedEnsemble",
+                                   "WeightedMeanEnsemble"):
+        json_ai.model["args"]["dtype_dict"] = json_ai.model["args"].get("dtype_dict", "$dtype_dict")
+
+    # Add implicit mixer arguments
     mixers = json_ai.model['args']['submodels']
     for i in range(len(mixers)):
-        if mixers[i]["module"] == "Unit":
-            pass
+        if not mixers[i].get("args", False):
+            mixers[i]["args"] = {}
 
-        elif mixers[i]["module"] in ("Neural", "NeuralTs"):
+        if mixers[i]["module"] == "Unit":
+            continue
+
+        # common
+        mixers[i]["args"]["target"] = mixers[i]["args"].get("target", "$target")
+        mixers[i]["args"]["dtype_dict"] = mixers[i]["args"].get("dtype_dict", "$dtype_dict")
+        mixers[i]["args"]["stop_after"] = mixers[i]["args"].get("stop_after", "$problem_definition.seconds_per_mixer")
+
+        # specific
+        if mixers[i]["module"] in ("Neural", "NeuralTs"):
             mixers[i]["args"]["target_encoder"] = mixers[i]["args"].get(
                 "target_encoder", "$encoders[self.target]"
             )
-            mixers[i]["args"]["target"] = mixers[i]["args"].get("target", "$target")
-            mixers[i]["args"]["dtype_dict"] = mixers[i]["args"].get(
-                "dtype_dict", "$dtype_dict"
-            )
             mixers[i]["args"]["net"] = mixers[i]["args"].get(
                 "net",
                 '"DefaultNet"'
@@ -555,10 +577,6 @@ def _add_implicit_values(json_ai: JsonAI) -> JsonAI:
                 mixers[i]["args"]["ts_analysis"] = mixers[i]["args"].get("ts_analysis", "$ts_analysis")
 
         elif mixers[i]["module"] == "LightGBM":
-            mixers[i]["args"]["target"] = mixers[i]["args"].get("target", "$target")
-            mixers[i]["args"]["dtype_dict"] = mixers[i]["args"].get(
-                "dtype_dict", "$dtype_dict"
-            )
             mixers[i]["args"]["input_cols"] = mixers[i]["args"].get(
                 "input_cols", "$input_cols"
             )
@@ -568,19 +586,11 @@ def _add_implicit_values(json_ai: JsonAI) -> JsonAI:
             mixers[i]["args"]["use_optuna"] = True
 
         elif mixers[i]["module"] == "Regression":
-            mixers[i]["args"]["target"] = mixers[i]["args"].get("target", "$target")
-            mixers[i]["args"]["dtype_dict"] = mixers[i]["args"].get(
-                "dtype_dict", "$dtype_dict"
-            )
             mixers[i]["args"]["target_encoder"] = mixers[i]["args"].get(
                 "target_encoder", "$encoders[self.target]"
             )
 
         elif mixers[i]["module"] == "LightGBMArray":
-            mixers[i]["args"]["target"] = mixers[i]["args"].get("target", "$target")
-            mixers[i]["args"]["dtype_dict"] = mixers[i]["args"].get(
-                "dtype_dict", "$dtype_dict"
-            )
             mixers[i]["args"]["input_cols"] = mixers[i]["args"].get(
                 "input_cols", "$input_cols"
             )
@@ -593,7 +603,6 @@ def _add_implicit_values(json_ai: JsonAI) -> JsonAI:
             mixers[i]["args"]["use_stl"] = mixers[i]["args"].get("use_stl", "False")
 
         elif mixers[i]["module"] == "NHitsMixer":
-            mixers[i]["args"]["target"] = mixers[i]["args"].get("target", "$target")
             mixers[i]["args"]["horizon"] = "$problem_definition.timeseries_settings.horizon"
             mixers[i]["args"]["window"] = "$problem_definition.timeseries_settings.window"
             mixers[i]["args"]["ts_analysis"] = mixers[i]["args"].get(
@@ -602,10 +611,6 @@ def _add_implicit_values(json_ai: JsonAI) -> JsonAI:
             problem_definition.fit_on_all = False  # takes too long otherwise
 
         elif mixers[i]["module"] in ("SkTime", "ProphetMixer", "ETSMixer", "ARIMAMixer"):
-            mixers[i]["args"]["target"] = mixers[i]["args"].get("target", "$target")
-            mixers[i]["args"]["dtype_dict"] = mixers[i]["args"].get(
-                "dtype_dict", "$dtype_dict"
-            )
             mixers[i]["args"]["ts_analysis"] = mixers[i]["args"].get(
                 "ts_analysis", "$ts_analysis"
             )
@@ -615,13 +620,6 @@ def _add_implicit_values(json_ai: JsonAI) -> JsonAI:
             # enforce fit_on_all if this mixer is specified
             problem_definition.fit_on_all = True
 
-        if "stop_after" not in mixers[i]["args"]:
-            mixers[i]["args"]["stop_after"] = "$problem_definition.seconds_per_mixer"
-
-    json_ai.model["args"]["target"] = json_ai.model["args"].get("target", "$target")
-    json_ai.model["args"]["data"] = json_ai.model["args"].get("data", "encoded_test_data")
-    json_ai.model["args"]["mixers"] = json_ai.model["args"].get("mixers", "$mixers")
-
     for name in json_ai.encoders:
         if name not in json_ai.dependency_dict:
             json_ai.dependency_dict[name] = []
@@ -673,13 +671,12 @@ def _add_implicit_values(json_ai: JsonAI) -> JsonAI:
         "explainer": {
             "module": "explain",
             "args": {
-                "timeseries_settings": "$problem_definition.timeseries_settings",
-                "positive_domain": "$statistical_analysis.positive_domain",
-                "anomaly_detection": "$problem_definition.anomaly_detection",
+                "problem_definition": "$problem_definition",
+                "stat_analysis": "$statistical_analysis",
                 "data": "data",
                 "encoded_data": "encoded_data",
                 "predictions": "df",
-                "analysis": "$runtime_analyzer",
+                "runtime_analysis": "$runtime_analyzer",
                 "ts_analysis": "$ts_analysis" if is_ts else None,
                 "target_name": "$target",
                 "target_dtype": "$dtype_dict[self.target]",
